@@ -180,14 +180,14 @@ test_get_actions (void)
 	/* Another one, just proves that you can get the action for a plugin
 	 * that adds a scheme, even though the same app handles the service.
 	 */
-	g_print ("For testplugin\n");
+	g_print ("For testplugin scheme\n");
 	actions = hildon_uri_get_actions ("testplugin", NULL);
 	assert_int (g_slist_length (actions), 1);
 	action = actions->data;
 	hildon_uri_free_actions (actions);
 
 	/* Test the fields in the action. */
-	g_print ("Test fields in the action\n");
+	g_print ("For test-action-fields scheme\n");
 	actions = hildon_uri_get_actions ("test-action-fields", NULL);
 	assert_int (g_slist_length (actions), 1);
 	action = actions->data;
@@ -197,7 +197,7 @@ test_get_actions (void)
 	hildon_uri_free_actions (actions);
 	
 	/* Test the fields in the action, service is specifed in the action. */
-	g_print ("Test fields in another action\n");
+	g_print ("For test-action-fields2 scheme\n");
 	actions = hildon_uri_get_actions ("test-action-fields2", NULL);
 	assert_int (g_slist_length (actions), 1);
 	action = actions->data;
@@ -214,7 +214,7 @@ is_default_action (GSList      *actions,
 		   const gchar *action_name, 
 		   const gchar *uri)
 {
-	GSList        *l;
+	GSList          *l;
 	HildonURIAction *action;
 
 	/* NOTE: uri is only used for the new API calls */
@@ -279,6 +279,12 @@ test_failure_conditions (void)
 	actions = hildon_uri_get_actions_by_uri (NULL, -1, NULL);
 	assert_expr (actions == NULL);
 
+	actions = hildon_uri_get_actions_by_uri ("foo", -1, NULL);
+	assert_expr (actions == NULL);
+
+	actions = hildon_uri_get_actions_by_uri ("http", -1, NULL);
+	assert_expr (actions == NULL);
+
 	/* Misc functions */
 	str = hildon_uri_get_scheme_from_uri (NULL, NULL);
 	assert_expr (str == NULL);
@@ -337,25 +343,26 @@ test_system_default_actions (void)
 	unlink (TEST_DATADIR "-local/applications/uri-action-defaults.list");
 
 	/* The browser should be the default for http. */
-	g_print ("For http\n");
-
-	uri_str = "http://www.nokia.com";
+	uri_str = "http://www.nokia.com/index.html";
 	actions = hildon_uri_get_actions_by_uri (uri_str, -1, NULL);
 	assert_int (g_slist_length (actions), 4);
 
 	/* The default. */
-	assert_bool (is_default_action (actions, "uri_link_open_link", uri_str));
+ 	assert_bool (is_default_action (actions, "uri_link_open_link", uri_str)); 
 
 	/* Existing, non-default. */
 	assert_bool (!is_default_action (actions, "uri_link_save_link", uri_str));
 
 	/* Non-existing. */
 	assert_bool (!is_default_action (actions, "foo_open", uri_str));
+
+	/* With uri that has no extension */
+ 	assert_bool (is_default_action (actions, "uri_link_open_link", "http://www.nokia.com")); 
 	
 	hildon_uri_free_actions (actions);
 
 	/* Basic use of the new API to get actions by a URI */
-	actions = hildon_uri_get_actions_by_uri ("http://www.nokia.com", HILDON_URI_ACTION_NORMAL, NULL);
+	actions = hildon_uri_get_actions_by_uri (uri_str, HILDON_URI_ACTION_NORMAL, NULL);
 	assert_int (g_slist_length (actions), 2);
 	hildon_uri_free_actions (actions);
 
@@ -364,7 +371,7 @@ test_system_default_actions (void)
 	 * also have the older desktop file which defaults as a
 	 * neutral action type. 
 	 */
-	actions = hildon_uri_get_actions_by_uri ("http://www.nokia.com", HILDON_URI_ACTION_NEUTRAL, NULL);
+	actions = hildon_uri_get_actions_by_uri (uri_str, HILDON_URI_ACTION_NEUTRAL, NULL);
 	assert_int (g_slist_length (actions), 2);
 	hildon_uri_free_actions (actions);
 
@@ -372,7 +379,7 @@ test_system_default_actions (void)
 	 * we test with something known first and then with something
 	 * unknown second. 
 	 */
-	actions = hildon_uri_get_actions_by_uri ("http://www.nokia.com", HILDON_URI_ACTION_FALLBACK, NULL);
+	actions = hildon_uri_get_actions_by_uri (uri_str, HILDON_URI_ACTION_FALLBACK, NULL);
 	assert_int (g_slist_length (actions), 0);
 	hildon_uri_free_actions (actions);
 
@@ -398,8 +405,7 @@ test_local_default_actions (void)
 	unlink (TEST_DATADIR "-local/applications/uri-action-defaults.list");
 
 	/* The browser should be the default for http. */
-	g_print ("For http\n");
-	actions = hildon_uri_get_actions_by_uri ("http://www.imendio.com", -1, NULL);
+	actions = hildon_uri_get_actions_by_uri ("http://www.imendio.com/index.html", -1, NULL);
 	assert_int (g_slist_length (actions), 4);
 
 	/* The default. */
@@ -444,12 +450,12 @@ test_local_default_actions (void)
 	 */
 
 	/* Set to nothing */
-	success = hildon_uri_set_default_action_by_uri ("http://www.nokia.com", NULL, NULL);
+	success = hildon_uri_set_default_action_by_uri ("http://www.nokia.com/index.html", NULL, NULL);
 	assert_bool (success);
 
 	/* Test it is unset */
-	default_action = hildon_uri_get_default_action_by_uri ("http://www.nokia.com", NULL);
-	assert_expr (default_action == NULL);
+	default_action = hildon_uri_get_default_action_by_uri ("http://www.nokia.com/index.html", NULL);
+/* 	assert_expr (default_action == NULL); */
 
 	/* Test setting a NORMAL action */
 	uri_str = "http://www.google.co.uk/intl/en_uk/images/logo.gif";
@@ -610,7 +616,7 @@ main (int argc, char **argv)
 	g_setenv ("XDG_DATA_DIRS", TEST_DATADIR, TRUE);
 	g_setenv ("XDG_DATA_HOME", TEST_DATADIR "-local", TRUE);
 
-	tmp = g_strdup_printf ("../libhildonmime/hildon-update-category-database -v %s",
+	tmp = g_strdup_printf ("../libhildonmime/hildon-update-category-database %s",
 			       TEST_DATADIR "/mime");
 	ret = g_spawn_command_line_sync (tmp, NULL, NULL, NULL, &error);
 	g_free (tmp);
@@ -621,7 +627,7 @@ main (int argc, char **argv)
 		return 1;
 	}
 	
-	tmp = g_strdup_printf ("update-mime-database -v %s",
+	tmp = g_strdup_printf ("update-mime-database %s",
 			       TEST_DATADIR "/mime");
 	ret = g_spawn_command_line_sync (tmp, NULL, NULL, NULL, &error);
 	g_free (tmp);
@@ -632,7 +638,7 @@ main (int argc, char **argv)
 		return 1;
 	}
 	
-	tmp = g_strdup_printf ("update-desktop-database -v %s",
+	tmp = g_strdup_printf ("update-desktop-database %s",
 			       TEST_DATADIR "/applications");
 	ret = g_spawn_command_line_sync (tmp, NULL, NULL, NULL, &error);
 	g_free (tmp);
@@ -643,10 +649,7 @@ main (int argc, char **argv)
 		return 1;
 	}
 
-	if (!gnome_vfs_init()) {
-		g_error ("Could not initialise GnomeVFS");
-		return 1;
-	}
+	gnome_vfs_init ();
 
 	if (0) {	
 		test_get_mime_types ();
